@@ -29,7 +29,7 @@ int main(int argc, char **argv) {
         return -1;
     }
 
-    char *rule = *(argv++);
+    char *rule = *(++argv);
     std::string rules(rule);
     ReadingLogsViaRuleMessage rlvrm(request_header, request_uri, request_body,
         response_headers, response_body, ip, rules);
