@@ -1,6 +1,6 @@
 /*
  * ModSecurity, http://www.modsecurity.org/
- * Copyright (c) 2015 Trustwave Holdings, Inc. (http://www.trustwave.com/)
+ * Copyright (c) 2015 - 2021 Trustwave Holdings, Inc. (http://www.trustwave.com/)
  *
  * You may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
@@ -32,14 +32,14 @@ namespace actions {
 
 class LogData : public Action {
  public:
-    explicit LogData(std::string action)
+    explicit LogData(const std::string &action) 
         : Action(action, RunTimeOnlyIfMatchKind) { }
 
     explicit LogData(std::unique_ptr<RunTimeString> z)
         : Action("logdata", RunTimeOnlyIfMatchKind),
             m_string(std::move(z)) { }
 
-    bool evaluate(Rule *rule, Transaction *transaction,
+    bool evaluate(RuleWithActions *rule, Transaction *transaction,
        std::shared_ptr<RuleMessage> rm) override;
 
     std::string data(Transaction *Transaction);
