@@ -1,6 +1,6 @@
 /*
  * ModSecurity, http://www.modsecurity.org/
- * Copyright (c) 2015 Trustwave Holdings, Inc. (http://www.trustwave.com/)
+ * Copyright (c) 2015 - 2021 Trustwave Holdings, Inc. (http://www.trustwave.com/)
  *
  * You may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
@@ -14,8 +14,11 @@
  */
 
 #include <string>
+#include <utility>
+#include <memory>
 
 #include "modsecurity/actions/action.h"
+#include "src/run_time_string.h"
 
 #ifndef SRC_ACTIONS_SET_RSC_H_
 #define SRC_ACTIONS_SET_RSC_H_
@@ -29,14 +32,18 @@ namespace actions {
 
 class SetRSC : public Action {
  public:
-    explicit SetRSC(std::string _action)
+    explicit SetRSC(const std::string &_action)
         : Action(_action) { }
 
-    bool evaluate(Rule *rule, Transaction *transaction) override;
+    explicit SetRSC(std::unique_ptr<RunTimeString> z)
+        : Action("setsrc", RunTimeOnlyIfMatchKind),
+            m_string(std::move(z)) { }
+
+    bool evaluate(RuleWithActions *rule, Transaction *transaction) override;
     bool init(std::string *error) override;
 
  private:
-    std::string m_collection_key;
+    std::unique_ptr<RunTimeString> m_string;
 };
 
 
