@@ -1,6 +1,6 @@
 /*
  * ModSecurity, http://www.modsecurity.org/
- * Copyright (c) 2015 Trustwave Holdings, Inc. (http://www.trustwave.com/)
+ * Copyright (c) 2015 - 2023 Trustwave Holdings, Inc. (http://www.trustwave.com/)
  *
  * You may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
@@ -15,12 +15,7 @@
 
 #include "src/actions/transformations/replace_nulls.h"
 
-#include <iostream>
 #include <string>
-#include <algorithm>
-#include <functional>
-#include <cctype>
-#include <locale>
 
 #include "modsecurity/transaction.h"
 #include "src/actions/transformations/transformation.h"
@@ -30,20 +25,20 @@ namespace modsecurity {
 namespace actions {
 namespace transformations {
 
-ReplaceNulls::ReplaceNulls(std::string action)
+ReplaceNulls::ReplaceNulls(const std::string &action) 
     : Transformation(action) {
     this->action_kind = 1;
 }
 
-std::string ReplaceNulls::evaluate(std::string value,
+std::string ReplaceNulls::evaluate(const std::string &val,
     Transaction *transaction) {
     int64_t i;
+    std::string value(val);
 
     i = 0;
     while (i < value.size()) {
         if (value.at(i) == '\0') {
-            value.erase(i, 1);
-            value.insert(i, " ", 1);
+            value[i] = ' ';
         } else {
             i++;
         }
