@@ -1,6 +1,6 @@
 /*
  * ModSecurity, http://www.modsecurity.org/
- * Copyright (c) 2015 Trustwave Holdings, Inc. (http://www.trustwave.com/)
+ * Copyright (c) 2015 - 2021 Trustwave Holdings, Inc. (http://www.trustwave.com/)
  *
  * You may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
@@ -69,7 +69,7 @@ namespace actions {
 namespace transformations {
 
 
-std::string Transformation::evaluate(std::string value,
+std::string Transformation::evaluate(const std::string &value,
     Transaction *transaction) {
     return value;
 }
