@@ -1,6 +1,6 @@
 /*
  * ModSecurity, http://www.modsecurity.org/
- * Copyright (c) 2015 Trustwave Holdings, Inc. (http://www.trustwave.com/)
+ * Copyright (c) 2015 - 2021 Trustwave Holdings, Inc. (http://www.trustwave.com/)
  *
  * You may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
@@ -33,13 +33,14 @@ namespace transformations {
 
 
 
-TrimLeft::TrimLeft(std::string action)
+TrimLeft::TrimLeft(const std::string &action) 
     : Trim(action) {
     this->action_kind = 1;
 }
 
-std::string TrimLeft::evaluate(std::string value,
+std::string TrimLeft::evaluate(const std::string &val,
     Transaction *transaction) {
+        std::string value(val);
     return *ltrim(&value);
 }
 
