@@ -1,6 +1,6 @@
 /*
  * ModSecurity, http://www.modsecurity.org/
- * Copyright (c) 2015 Trustwave Holdings, Inc. (http://www.trustwave.com/)
+ * Copyright (c) 2015 - 2021 Trustwave Holdings, Inc. (http://www.trustwave.com/)
  *
  * You may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
@@ -27,12 +27,13 @@ namespace actions {
 namespace transformations {
 
 
-UpperCase::UpperCase(std::string a)
+UpperCase::UpperCase(const std::string &a)
     : Transformation(a) {
 }
 
-std::string UpperCase::evaluate(std::string value,
+std::string UpperCase::evaluate(const std::string &val,
     Transaction *transaction) {
+    std::string value(val);
     std::locale loc;
 
     for (std::string::size_type i=0; i < value.length(); ++i) {
