@@ -1,6 +1,6 @@
 /*
  * ModSecurity, http://www.modsecurity.org/
- * Copyright (c) 2015 - 2021 Trustwave Holdings, Inc. (http://www.trustwave.com/)
+ * Copyright (c) 2015 - 2023 Trustwave Holdings, Inc. (http://www.trustwave.com/)
  *
  * You may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
@@ -21,6 +21,7 @@
 
 #include <fstream>
 
+#include "modsecurity/transaction.h"
 #include "modsecurity/rule_message.h"
 #include "src/audit_log/writer/https.h"
 #include "src/audit_log/writer/parallel.h"
@@ -61,7 +62,8 @@ AuditLog::AuditLog()
     m_status(NotSetLogStatus),
     m_type(NotSetAuditLogType),
     m_relevant(""),
-    m_writer(NULL) { }
+    m_writer(NULL),
+    m_ctlAuditEngineActive(false) { }
 
 
 AuditLog::~AuditLog() {
@@ -210,7 +212,8 @@ bool AuditLog::setType(AuditLogType audit_type) {
 bool AuditLog::init(std::string *error) {
     audit_log::writer::Writer *tmp_writer;
 
-    if (m_status == OffAuditLogStatus || m_status == NotSetLogStatus) {
+    if ((m_status == OffAuditLogStatus || m_status == NotSetLogStatus)
+        && !m_ctlAuditEngineActive) {
         if (m_writer) {
             delete m_writer;
             m_writer = NULL;
@@ -241,21 +244,6 @@ bool AuditLog::init(std::string *error) {
         return false;
     }
 
-    /* Sanity check */
-    if (m_status == RelevantOnlyAuditLogStatus) {
-        if (m_relevant.empty()) {
-            /*
-             error->assign("m_relevant cannot be null while status is set to " \
-                "RelevantOnly");
-             return false;
-             */
-            // FIXME: this should be a warning. There is not point to
-            // have the logs on relevant only if nothing is relevant.
-            //
-            // Not returning an error to keep the compatibility with v2.
-        }
-    }
-
     if (m_writer) {
         delete m_writer;
     }
@@ -290,19 +278,25 @@ bool AuditLog::saveIfRelevant(Transaction *transaction) {
 
 bool AuditLog::saveIfRelevant(Transaction *transaction, int parts) {
     bool saveAnyway = false;
-    if (m_status == OffAuditLogStatus || m_status == NotSetLogStatus) {
+
+    AuditLogStatus transactionAuditLogStatus(m_status);
+    if (transaction->m_ctlAuditEngine != NotSetLogStatus) {
+        transactionAuditLogStatus = transaction->m_ctlAuditEngine;
+    }
+
+    if (transactionAuditLogStatus == OffAuditLogStatus || transactionAuditLogStatus == NotSetLogStatus) {
         ms_dbg_a(transaction, 5, "Audit log engine was not set.");
         return true;
     }
 
-    for (RuleMessage &i : transaction->m_rulesMessages) {
+    for (const RuleMessage &i : transaction->m_rulesMessages) {
         if (i.m_noAuditLog == false) {
             saveAnyway = true;
             break;
         }
     }
 
-    if ((m_status == RelevantOnlyAuditLogStatus
+    if ((transactionAuditLogStatus == RelevantOnlyAuditLogStatus
         && this->isRelevant(transaction->m_httpCodeReturned) == false)
         && saveAnyway == false) {
         ms_dbg_a(transaction, 9, "Return code `" +
@@ -368,6 +362,10 @@ bool AuditLog::merge(AuditLog *from, std::string *error) {
         m_format = from->m_format;
     }
 
+    if (from->m_ctlAuditEngineActive) {
+        m_ctlAuditEngineActive = from->m_ctlAuditEngineActive;
+    }
+
     return init(error);
 }
 
