@@ -1,6 +1,6 @@
 /*
  * ModSecurity, http://www.modsecurity.org/
- * Copyright (c) 2015 - 2021 Trustwave Holdings, Inc. (http://www.trustwave.com/)
+ * Copyright (c) 2015 - 2023 Trustwave Holdings, Inc. (http://www.trustwave.com/)
  *
  * You may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
@@ -98,7 +98,6 @@ class LMDB :
     public Collection {
  public:
     explicit LMDB(const std::string &name);
-    void store(std::string key, std::string value) override;
 
     bool storeOrUpdateFirst(const std::string &key,
         const std::string &value) override;
@@ -108,6 +107,8 @@ class LMDB :
 
     void del(const std::string& key) override;
 
+    void setExpiry(const std::string& key, int32_t expiry_seconds) override;
+
     std::unique_ptr<std::string> resolveFirst(const std::string& var) override;
 
     void resolveSingleMatch(const std::string& var,
@@ -124,6 +125,8 @@ class LMDB :
     void string2val(const std::string& str, MDB_val *val);
     void inline lmdb_debug(int rc, const std::string &op, const std::string &scope);
 
+    void delIfExpired(const std::string& key);
+
     MDB_env *m_env;
     MDB_dbi m_dbi;
     bool isOpen;
