@@ -1,6 +1,6 @@
 /*
  * ModSecurity, http://www.modsecurity.org/
- * Copyright (c) 2015 Trustwave Holdings, Inc. (http://www.trustwave.com/)
+ * Copyright (c) 2015 - 2021 Trustwave Holdings, Inc. (http://www.trustwave.com/)
  *
  * You may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
@@ -33,11 +33,6 @@
 namespace modsecurity {
 namespace operators {
 
-bool GeoLookup::debug(Transaction *transaction, int x, std::string a) {
-    ms_dbg_a(transaction, x, a);
-    return true;
-}
-
 
 bool GeoLookup::evaluate(Transaction *trans, const std::string &exp) {
     using std::placeholders::_1;
