@@ -1,6 +1,6 @@
 /*
  * ModSecurity, http://www.modsecurity.org/
- * Copyright (c) 2015 Trustwave Holdings, Inc. (http://www.trustwave.com/)
+ * Copyright (c) 2015 - 2021 Trustwave Holdings, Inc. (http://www.trustwave.com/)
  *
  * You may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
@@ -32,7 +32,10 @@ class GeoLookup : public Operator {
     bool evaluate(Transaction *transaction, const std::string &exp) override;
 
  protected:
-    bool debug(Transaction *transaction, int x, std::string a);
+    bool debug(Transaction *transaction, int x, const std::string &a) {
+        ms_dbg_a(transaction, x, a);
+        return true;
+    }
 };
 
 }  // namespace operators
