@@ -935,7 +935,7 @@ int Multipart::process_part_header(std::string *error, int offset) {
                 "Multipart: Added part header \"" + header_name \
                 + "\" \"" + header_value + "\".");
             if (len_without_termination > 0) {
-                m_mpp->m_last_header_line.assign(m_buf);
+                m_mpp->m_last_header_line.assign(m_buf, len_without_termination);
             } else {
                 m_mpp->m_last_header_line.assign("");
             }
@@ -1198,15 +1198,9 @@ int Multipart::multipart_complete(std::string *error) {
         size_t offset = m_transaction->m_variableOffset + 1;
 
         if (m->m_type == MULTIPART_FILE) {
-            std::string tmp_name;
-            std::string name;
-        if (m->m_tmp_file && !m->m_tmp_file->getFilename().empty()) {
-            tmp_name.assign(m->m_tmp_file->getFilename());
-            m_transaction->m_variableFilesTmpNames.set(m->m_tmp_file->getFilename(),
-                m->m_tmp_file->getFilename(), m->m_filenameOffset);
-            }
-            if (!m->m_filename.empty()) {
-                name.assign(m->m_filename);
+            if (m->m_tmp_file && !m->m_tmp_file->getFilename().empty()) {
+                m_transaction->m_variableFilesTmpNames.set(m->m_tmp_file->getFilename(),
+                    m->m_tmp_file->getFilename(), m->m_filenameOffset);
             }
 
             m_transaction->m_variableFiles.set(m->m_name,
