@@ -1,6 +1,6 @@
 /*
  * ModSecurity, http://www.modsecurity.org/
- * Copyright (c) 2015 Trustwave Holdings, Inc. (http://www.trustwave.com/)
+ * Copyright (c) 2015 - 2021 Trustwave Holdings, Inc. (http://www.trustwave.com/)
  *
  * You may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
@@ -31,8 +31,8 @@ class Md5 {
  public:
     Md5() { }
 
-    static std::string hexdigest(std::string& input);
-    static std::string digest(std::string& input);
+    static std::string hexdigest(const std::string& input);
+    static std::string digest(const std::string& input);
 };
 
 }  // namespace Utils
