@@ -1,6 +1,6 @@
 /*
  * ModSecurity, http://www.modsecurity.org/
- * Copyright (c) 2015 Trustwave Holdings, Inc. (http://www.trustwave.com/)
+ * Copyright (c) 2015 - 2021 Trustwave Holdings, Inc. (http://www.trustwave.com/)
  *
  * You may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
@@ -27,7 +27,7 @@ namespace modsecurity_test {
 
 class UnitTest {
  public:
-    static UnitTest *from_yajl_node(yajl_val &);
+    static UnitTest *from_yajl_node(const yajl_val &);
 
     std::string print();
 
